@@ -53,9 +53,74 @@ This method is  called when a result for a specific method-call is available.
 
 ``qam.qam_proxy.QAMException`` :
   This is the class for internal exceptions. An internal exception would be everything raised by the QAMServer.
-``qam.qam_proxy.WAMMEthodNotFoundException`` :
+``qam.qam_proxy.QAMMEthodNotFoundException`` :
   This exception is created, if the method called by the QAMProxy isn't registerd on the QAMServer.
 
+=======
+Usage
+=======
+
+Calling a method without callback
+---------------------------------
+An example-usage of the QAMProxy. The code shows how to call a method that is registered on QAMServer.
+
+   >>> from qam.qam_proxy import QAMProxy, QAMMethodNotFoundException, QAMException
+   >>> qam_proxy = QAMProxy(hostname="localhost",
+   ...                    port=5672,
+   ...                    username='guest',
+   ...                    password='guest',
+   ...                    vhost='/',
+   ...                    server_id='qamserver',
+   ...                    client_id='qamproxy')
+   ...
+   >>> result = qam_proxy.add(2,3) # name of method registered on QAMServer
+   >>> qam_proxy.close()
+   
+Calling a method with callback
+------------------------------
+An example-usage of the QAMProxy with callback functions.
+
+   >>> from qam.qam_proxy import QAMProxy, QAMMethodNotFoundException, QAMException
+   >>> qam_proxy = QAMProxy(hostname="localhost",
+   ...                    port=5672,
+   ...                    username='guest',
+   ...                    password='guest',
+   ...                    vhost='/',
+   ...                    server_id='qamserver',
+   ...                    client_id='qamproxy')
+   ...
+   ... # defining functions for callback
+   >>> def success(arg):
+   ...    print arg
+   >>> def error(arg):
+   ...    # if an error occours on QAMServer
+   ...    print arg 
+   >>> uid = qam_proxy.callback(success, error).adder_function(2,4)
+   >>> while True:
+   ...    state = qam_proxy.get_callback_state(uid)
+   ...    if state == 2 :
+   ...        # execution of callback finished
+   ...        break
+   ...
+   >>> qam_proxy.close()
+   
+ 
+Calling a registered Class
+------------------------------
+An example-usage of the QAMProxy for calling a registered class-instance on QAMServer.
+
+   >>> from qam.qam_proxy import QAMProxy, QAMMethodNotFoundException, QAMException
+   >>> qam_proxy = QAMProxy(hostname="localhost",
+   ...                    port=5672,
+   ...                    username='guest',
+   ...                    password='guest',
+   ...                    vhost='/',
+   ...                    server_id='qamserver',
+   ...                    client_id='qamproxy')
+   ...
+   >>> result = qam_proxy.testclass.adder_function(2,4)
+   >>> qam_proxy.close()
+
 =======
 Classes
 =======
@@ -151,9 +216,12 @@ class QAMProxy:
     """
     The PublisherThread, the ConsumerThread and the CallbackObserverTrhead are being stopped (kill-signal set to True).
     """
-    self.publisher_thread.exit()
-    self.consumer_thread.exit()
-    self.callback_observer_thread.exit()
+    if self.publisher_thread != None:
+      self.publisher_thread.exit()
+    if self.consumer_thread != None:
+      self.consumer_thread.exit()
+    if self.callback_observer_thread != None:
+      self.callback_observer_thread.exit()
     
   def callback(self, callback_method, exception_method=None):
     """
