@@ -1,7 +1,79 @@
 """
 
-The QAM Server executes remote method calls.
+The QAM Server executes remote method calls received from a QAMProxy.
 
+**The QAMServer consists of the following classes:**
+
+``qam.qam_server.QAMServer`` :
+  The *QAMServer* class provides the basic functions for registering methods and class-instances which could be executed and called by the server.
+  Further the QAMServer receives messages (remote-method-calls) from an amqp-queue and passes them the ExecuteMethodThread which executes one method-call.
+  
+``qam.qam_server.ExecuteMethodThread`` :
+  The ExecuteMethodThread is called by the QAMServer and executes one method-call. 
+  The QAMServer receives the method-calls and then the QAMServer starts an ExecuteMethodThread for executing the method.
+  
+``qam.qam_server.PublisherThread`` :
+  The PublisherThread sends the result for one method-call back to QAMProxy. The resuls are stored in a queue. 
+  The PublisherThread takes continuously a result from the queue and sends it. 
+  If the queue is empty, the PublisherThread waits, until a new result is available for sending.
+
+**The QAMServer consists of the following Exceptions:**
+
+``qam.qam_server.QAMMEthodNotFoundException`` :
+  This exception signals, that the method the QAMProxy wanted to call isn't registered on the QAMServer. The exception is sent back to QAMProxy as result.
+
+=======
+Usage
+=======
+Register methods
+----------------
+An example-usage of the QAMServer. The code shows how to register a function.
+
+   >>> from qam.qam_server import QAMServer
+   >>> qam_server = QAMServer(hostname="localhost",
+   ...                    port=5672,
+   ...                    username='guest',
+   ...                    password='guest',
+   ...                    vhost='/',
+   ...                    server_id='qamserver')
+   ...
+   >>> def adder_function(x, y):    
+   ...    return x + y
+   ...
+   >>> qam_server.register_function(adder_function, 'add')
+   ...
+   ... # it is also possible to register the adder_function as follows:
+   ... # qam_server.register_function(adder_function)
+   ... # the method-name for registering in this case is adder_function.__name__
+   ...
+   >>> qam_server.serve()
+   
+Register class-instances
+------------------------
+An example-usage of the QAMServer. The code shows how to register class-instance.
+
+   >>> from qam.qam_server import QAMServer
+   >>> qam_server = QAMServer(hostname="localhost",
+   ...                    port=5672,
+   ...                    username='guest',
+   ...                    password='guest',
+   ...                    vhost='/',
+   ...                    server_id='qamserver')
+   ...
+   >>> class TestClass():
+   ...    def __init__(self):
+   ...        pass
+   ...    def adder_function(self,a,b):
+   ...        return a+b
+   ...
+   >>> testclass = TestClass()
+   >>> qam_server.register_class(testclass,'testclass')
+   >>> qam_server.serve()
+
+
+=======
+Classes
+=======
 """
 __author__ = "christian"
 __date__ = "$Aug 14, 2009 8:24:39 PM$"
